aboutsummaryrefslogtreecommitdiffstats
path: root/lib/folder/folder-interface.go
diff options
context:
space:
mode:
authorSebastien Douheret <sebastien.douheret@iot.bzh>2017-08-18 01:04:02 +0200
committerSebastien Douheret <sebastien.douheret@iot.bzh>2017-08-18 01:04:02 +0200
commit8f44cc7217ce48f3f94c8ea3f037cdf011c4493b (patch)
treea93c483370e6ad64a7440241cfb7c21beb6021ba /lib/folder/folder-interface.go
parent4feef5296bf3aea331fdde4cd7b94ee2322a907e (diff)
Add folder synchronization status.
Also add ability to force re-synchronization.
Diffstat (limited to 'lib/folder/folder-interface.go')
-rw-r--r--lib/folder/folder-interface.go21
1 files changed, 15 insertions, 6 deletions
diff --git a/lib/folder/folder-interface.go b/lib/folder/folder-interface.go
index b76b3f3..c04cbd7 100644
--- a/lib/folder/folder-interface.go
+++ b/lib/folder/folder-interface.go
@@ -14,16 +14,24 @@ const (
StatusErrorConfig = "ErrorConfig"
StatusDisable = "Disable"
StatusEnable = "Enable"
+ StatusPause = "Pause"
+ StatusSyncing = "Syncing"
)
+type EventCBData map[string]interface{}
+type EventCB func(cfg *FolderConfig, data *EventCBData)
+
// IFOLDER Folder interface
type IFOLDER interface {
- Add(cfg FolderConfig) (*FolderConfig, error) // Add a new folder
- GetConfig() FolderConfig // Get folder public configuration
- GetFullPath(dir string) string // Get folder full path
- Remove() error // Remove a folder
- Sync() error // Force folder files synchronization
- IsInSync() (bool, error) // Check if folder files are in-sync
+ NewUID(suffix string) string // Get a new folder UUID
+ Add(cfg FolderConfig) (*FolderConfig, error) // Add a new folder
+ GetConfig() FolderConfig // Get folder public configuration
+ GetFullPath(dir string) string // Get folder full path
+ Remove() error // Remove a folder
+ RegisterEventChange(cb *EventCB, data *EventCBData) error // Request events registration (sent through WS)
+ UnRegisterEventChange() error // Un-register events
+ Sync() error // Force folder files synchronization
+ IsInSync() (bool, error) // Check if folder files are in-sync
}
// FolderConfig is the config for one folder
@@ -33,6 +41,7 @@ type FolderConfig struct {
ClientPath string `json:"path"`
Type FolderType `json:"type"`
Status string `json:"status"`
+ IsInSync bool `json:"isInSync"`
DefaultSdk string `json:"defaultSdk"`
// Not exported fields from REST API point of view